==> kubernetes-model-core-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/FlexVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FlexVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.FlexVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.FlexVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.FlexVolumeSource,io.fabric8.kubernetes.api.model.FlexVolumeSourceBuilder>{
  public FlexVolumeSourceBuilder() {
    this(false);
  }
  public FlexVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new FlexVolumeSource(), validationEnabled);
  }
  public FlexVolumeSourceBuilder(io.fabric8.kubernetes.api.model.FlexVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public FlexVolumeSourceBuilder(io.fabric8.kubernetes.api.model.FlexVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FlexVolumeSource(), validationEnabled);
  }
  public FlexVolumeSourceBuilder(io.fabric8.kubernetes.api.model.FlexVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.FlexVolumeSource instance) {
    this(fluent, instance, false);
  }
  public FlexVolumeSourceBuilder(io.fabric8.kubernetes.api.model.FlexVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.FlexVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDriver(instance.getDriver()); 
    fluent.withFsType(instance.getFsType()); 
    fluent.withOptions(instance.getOptions()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FlexVolumeSourceBuilder(io.fabric8.kubernetes.api.model.FlexVolumeSource instance) {
    this(instance,false);
  }
  public FlexVolumeSourceBuilder(io.fabric8.kubernetes.api.model.FlexVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDriver(instance.getDriver()); 
    this.withFsType(instance.getFsType()); 
    this.withOptions(instance.getOptions()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.FlexVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.FlexVolumeSource build() {
    FlexVolumeSource buildable = new FlexVolumeSource(fluent.getDriver(),fluent.getFsType(),fluent.getOptions(),fluent.getReadOnly(),fluent.getSecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FlexVolumeSourceBuilder that = (FlexVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/FlexVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FlexVolumeSourceBuilder extends FlexVolumeSourceFluentImpl<FlexVolumeSourceBuilder> implements VisitableBuilder<FlexVolumeSource,FlexVolumeSourceBuilder>{
  public FlexVolumeSourceBuilder() {
    this(false);
  }
  public FlexVolumeSourceBuilder(Boolean validationEnabled) {
    this(new FlexVolumeSource(), validationEnabled);
  }
  public FlexVolumeSourceBuilder(FlexVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public FlexVolumeSourceBuilder(FlexVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FlexVolumeSource(), validationEnabled);
  }
  public FlexVolumeSourceBuilder(FlexVolumeSourceFluent<?> fluent,FlexVolumeSource instance) {
    this(fluent, instance, false);
  }
  public FlexVolumeSourceBuilder(FlexVolumeSourceFluent<?> fluent,FlexVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDriver(instance.getDriver()); 
    fluent.withFsType(instance.getFsType()); 
    fluent.withOptions(instance.getOptions()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FlexVolumeSourceBuilder(FlexVolumeSource instance) {
    this(instance,false);
  }
  public FlexVolumeSourceBuilder(FlexVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDriver(instance.getDriver()); 
    this.withFsType(instance.getFsType()); 
    this.withOptions(instance.getOptions()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  FlexVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public FlexVolumeSource build() {
    FlexVolumeSource buildable = new FlexVolumeSource(fluent.getDriver(),fluent.getFsType(),fluent.getOptions(),fluent.getReadOnly(),fluent.getSecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
